String,StringBuffer和StringBuilder的异同
String,StringBuffer和StringBuilder的的源码已经在本博客的JDK源码学习系列中有了详细的介绍:
String 源码: http://blog.csdn.net/sheepmu/article/details/23303837
StringBuffer 和StringBuil...
分类:
其他 时间:
2014-06-03 05:43:30
收藏:
0 评论:
0 赞:
0 阅读:
430
There is no systematic design for shared resource access priority in platform side, and there is no interface provided by
platform that can be used by application to do bandwidth management optimizat...
分类:
其他 时间:
2014-06-03 04:52:10
收藏:
0 评论:
0 赞:
0 阅读:
396
原创博客,转载请:http://blog.csdn.net/zhjm07054115/article/details/27577181...
分类:
其他 时间:
2014-06-03 04:51:28
收藏:
0 评论:
0 赞:
0 阅读:
671
Given a singly linked list
L: L0→L1→…→Ln-1→Ln,
reorder it to: L0→Ln→L1→Ln-1→L2→Ln-2→…
You must do this in-place without altering the nodes' values.
For example,
Given {1,2,3,4}, r...
分类:
其他 时间:
2014-06-03 03:11:03
收藏:
0 评论:
0 赞:
0 阅读:
399
成功不在于你有多复杂,而是在于你有多简单!...
分类:
其他 时间:
2014-06-03 02:40:50
收藏:
0 评论:
0 赞:
0 阅读:
368
Spark开源的各模块组成结构...
分类:
其他 时间:
2014-06-03 04:05:56
收藏:
0 评论:
0 赞:
0 阅读:
354
好的编程习惯...
分类:
其他 时间:
2014-06-03 04:14:57
收藏:
0 评论:
0 赞:
0 阅读:
332
仲裁寄存器default值:
The default values of CPUARB, IDMAARB, SDMAARB, and UCARB are sufficient for most applications. These registers define priorities that are internal to the C66x CorePac. The MDMAARBU...
分类:
其他 时间:
2014-06-03 03:51:46
收藏:
0 评论:
0 赞:
0 阅读:
482
看了erlang的一些开源网络框架RabbitMQ、Ranch,他们都使用多个进程同时accept一个socket。这种方式在使得socket端口监听的工作分担了更多的调度机会,但是,在erlang中,socket接受一个新连接后,如果想让另一个进程处理消息,就要显式的调用gen_tcp:controlling_process(Socket, Pid)。所以问题来了,erlang多个进程同时监听一个socket安全吗?文章将会重点讨论这个问题及对这个问题做优化。...
分类:
其他 时间:
2014-06-03 03:51:09
收藏:
0 评论:
0 赞:
0 阅读:
408
已知一副RGB图像中的的像素值,利用matlab将其分割出来并以二进制图像形式显示:
%extract.m
clear all;
I=imread('new_original.png');
figure,imshow(I),title('Original Image');
bw=im2bw(I,0.3);
%figure,imshow(bw),title('Gray Image');
rgb=[...
分类:
其他 时间:
2014-06-03 02:44:43
收藏:
0 评论:
0 赞:
0 阅读:
465
车牌识别 手机测试...
分类:
其他 时间:
2014-06-03 01:33:57
收藏:
0 评论:
0 赞:
0 阅读:
360
车牌识别 S5PV210测试...
分类:
其他 时间:
2014-06-03 04:42:10
收藏:
0 评论:
0 赞:
0 阅读:
414
前言
JQuery EasyUI提供的组件包括功能强大的DataGrid,TreeGrid、面板、下拉组合等。用户可以组合使用这些组件,也可以单独使用其中一个。(使用的形式是以插件的方式提供的)
EasyUI体系结构
EasyUI所有的插件主要分为六大部分。Base基础、Layout布局、Menu&a...
分类:
其他 时间:
2014-06-03 04:19:30
收藏:
0 评论:
0 赞:
0 阅读:
398
在了解完easyui的parser(解析器)之后,接下来就是easyloader(简单加载器)的学习了。
什么是EasyLoader
正如其名字一样easyloader的作用是为了动态的加载组件所需的js文件,这体现了EasyUI作为轻量级框架对性能的合理掌握(可以动态的加载所需组件),不过一般而言很少使用到easyloader(会给使用者带来一定的难度)。那么使用EasyL...
分类:
其他 时间:
2014-06-03 03:18:55
收藏:
0 评论:
0 赞:
0 阅读:
338
监控平台架构设计...
分类:
其他 时间:
2014-06-03 03:57:10
收藏:
0 评论:
0 赞:
0 阅读:
508
BNUOJ 34981 A Matrix
题目地址:BNUOJ 34981
题意:
给你一个把一个排列放到矩阵里面的算法和矩阵,要你从矩阵写出排列。
如果答案有多个,输出翻转后字典序最大的那个。
分析:
想了半天只能想到链表版的,而且很可能TLE,看了帆神的题解后豁然开朗..Orz..
代码:
/*
* Author: illuz
*...
分类:
其他 时间:
2014-06-03 01:55:18
收藏:
0 评论:
0 赞:
0 阅读:
444
#include
__global__ void childKernel(int i)
{
int tid = blockIdx.x*blockDim.x+threadIdx.x;
printf("parent:%d,child:%d\n",i,tid);
for(int j=i;j<i+10;j++)
{
printf(",%d",j);
}
printf("\n");...
分类:
其他 时间:
2014-06-03 03:56:28
收藏:
0 评论:
0 赞:
0 阅读:
344
上面一篇已经jiang...
分类:
其他 时间:
2014-06-03 01:42:57
收藏:
0 评论:
0 赞:
0 阅读:
766
Knight Moves
Time Limit: 1000MS
Memory Limit: 30000K
Total Submissions: 20913
Accepted: 9702
Description
Background
Mr Somuro...
分类:
其他 时间:
2014-06-03 04:00:27
收藏:
0 评论:
0 赞:
0 阅读:
455
SICP 习题 1.37是一条很长的题目,主要讲的是无穷连分式。无穷连分式对我来说又是一个陌生的概念,于是又去百度了一番,发现无穷连分式也是一个很有意思的话题,涉及到无理数的表达。不过我建议大家还是暂时不要深入思考它的数学含义,一旦开始思考可能你又会跳进数学的深渊中不可自拔。无穷连分式的形式如下:就像书中说到的,作为无穷连分式的一个特殊例子,如果N和D都为1的话,f= 1/ φ, 这点可以结合我们...
分类:
其他 时间:
2014-06-03 03:31:18
收藏:
0 评论:
0 赞:
0 阅读:
371